#
# spec file for package libqcow
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define lname	libqcow1
Name:           libqcow
Version:        20240308
Release:        1.4
Summary:        Library and tooling to access the QEMU Copy-On-Write (QCOW) image format
License:        GFDL-1.1-or-later AND LGPL-3.0-or-later AND GFDL-1.3-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libqcow
Source:         https://github.com/libyal/libqcow/releases/download/%version/libqcow-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libqcow/releases/download/%version/libqcow-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source8:        QEMU_Copy-On-Write_file_format.pdf
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcaes) >= 20240114
BuildRequires:  pkgconfig(libcdata) >= 20240103
BuildRequires:  pkgconfig(libcerror) >= 20240101
BuildRequires:  pkgconfig(libcfile) >= 20240106
BuildRequires:  pkgconfig(libclocale) >= 20240107
BuildRequires:  pkgconfig(libcnotify) >= 20240108
BuildRequires:  pkgconfig(libcpath) >= 20240109
BuildRequires:  pkgconfig(libcsplit) >= 20240110
BuildRequires:  pkgconfig(libcthreads) >= 20240102
BuildRequires:  pkgconfig(libfcache) >= 20240112
BuildRequires:  pkgconfig(libfdata) >= 20240114
BuildRequires:  pkgconfig(libuna) >= 20240130
BuildRequires:  pkgconfig(openssl) >= 1.0
BuildRequires:  pkgconfig(zlib) >= 1.2.5
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
Library and tooling to access the QEMU Copy-On-Write (QCOW) image format.
QCOW formats v1 and v2 in compressed or encrypted form are supported.
Not supported are backing file-based snapshots and in-image snapshots.

%package -n %lname
Summary:        Library to access the QEMU Copy-On-Write (QCOW) image format
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
Library to access the QEMU Copy-On-Write (QCOW) image format.
QCOW formats v1 and v2 in compressed or encrypted form are supported.
Not supported are backing file-based snapshots and in-image snapshots.

%package tools
Summary:        Tools to access the QEMU Copy-On-Write (QCOW) image format
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
Tools to access the QEMU Copy-On-Write (QCOW) image format.
QCOW formats v1 and v2 in compressed or encrypted form are supported.
Not supported are backing file-based snapshots and in-image snapshots.

%package devel
Summary:        Development files for libqcow
License:        GFDL-1.1-or-later AND LGPL-3.0-or-later AND GFDL-1.3-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libqcow is a library to access the QEMU Copy-On-Write (QCOW) image format.

This subpackage contains libraries and header files for developing
applications that want to make use of libqcow.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type --enable-python \
	PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find %buildroot -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libqcow.so.*

%files -n %name-tools
%license COPYING*
%_bindir/qcow*
%_mandir/man1/qcow*.1*

%files -n %name-devel
%doc QEMU_Copy-On-Write_file_format.pdf
%license COPYING*
%_includedir/libqcow.h
%_includedir/libqcow/
%_libdir/libqcow.so
%_libdir/pkgconfig/libqcow.pc
%_mandir/man3/libqcow.3*

%files %python_files
%license COPYING*
%python_sitearch/pyqcow.so

%changelog
* Sun Mar 10 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240308
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Sat Nov 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231125
  * Python build updates and Unicode improvements
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Thu Nov 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221124
  * A refcounting issue with the Python module was fixed
* Thu Oct 27 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221026
  * Updates to fallback DEFLATE support
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds.
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210419 (3f7562bd)
  * No changelog was provided
- Add system-libs.patch
* Thu Dec 24 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- Update to v0~20201213
  * Worked on format support
  * Code clean-up
* Tue May 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v0~20191221 (no changelog)
* Sat May  9 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 subpackage.  Python2 is no longer in factory.
* Sun Jun  2 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20181227
  * Worked on mount tool
  * Added a new API call "is_locked"
* Wed Jan 10 2018 Greg.Freemyer@gmail.com
- fix upgrade issue caused by rename python-* to python2-*
* Wed Oct  4 2017 Greg.Freemyer@gmail.com
- remove unversioned Provides: pyqcow,
  depend on python{23}-libqcow instead
* Sat Feb 25 2017 Greg.Freemyer@gmail.com
- update to v0~20170222
- change RPM Group to Development/Languages/Python
- review and update libyal dependencies
- add python3 binding sub-package
- fix Summary and Description fields which had wrong info in them
* Wed Jan 27 2016 Greg.Freemyer@gmail.com
- update to v0~20160123
  * worked on fallback inflate implementation
  * Changes to Python bindings
  * fixes for rpmbuild
  * 2016 update
  * Changes to Python bindings
  * worked on tests
* Fri Jan  9 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * worked on test scripts
  * worked on multi-threading support
  * code clean up
  * worked on version 3 support
  * removed deprecated functions:
  - libqcow_file_read_random
  - pyqcow file.read_random
  * bug fix in Python-bindings
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using libcstring from OBS, not internal version
- start using libcsystem from OBS, not internal version
- start using libfcache from OBS, not internal version
- start using libfdata from OBS, not internal version
* Mon Aug 25 2014 Greg.Freemyer@gmail.com
- add BuildRequires for fuse, openssl, and zlib.  Allows parsing of more complex containers.
- move %%doc statement after %%attr statement in python sub-package
- add Requires: %%lname = %%version to python section to make sure they stay in sync
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- add %%doc line to python sub-package
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- initial package in OBS (v0~20140729)
